#!/usr/bin/env python
# Copyright 2012 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Common resources for integration tests."""

__metaclass__ = type
__all__ = [
    'IntegrationTestBase',
    ]


class IntegrationTestBase:

    banner_width = 70
    test_type = None

    def __init__(self, args):
        self.args = args

    def banner(self, msg, width=banner_width):
        print '*' * width
        print '* ' + msg.ljust(width - 4) + ' *'
        print '*' * width

    def set_up(self):
        self.banner(
            'Setting up the test environment for {}.'.format(self.test_type))

    def tear_down(self):
        self.banner('Cleaning up.')

    def check_environment(self):
        self.banner('Checking test environment.')

    def do_test(self):
        self.banner('Running integration tests for {}.'.format(self.test_type))

    def run(self):
        self.check_environment()
        try:
            self.set_up()
            try:
                self.do_test()
            except Exception as err:
                self.banner('Test failed.  Sorry.')
                print err
                return 1
            else:
                self.banner('Test succeeded.')
                return 0
        finally:
            self.tear_down()
