#!/usr/bin/env python
# Copyright 2012 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Tests for the update subcommand."""

import unittest

from lpsetup import handlers
from lpsetup.subcommands import update
from lpsetup.tests.utils import (
    get_random_string,
    StepsBasedSubCommandTestMixin,
    )


def get_arguments():
    return (
        '--external-path', get_random_string(),
        '--use-http',
        '-e', '../devel',
        '-W', '~/' + get_random_string(),
        )

init_dir_step = (
    update.initialize_directories, ['working_dir', 'external_path'])
update_dep_step = (
    update.update_dependencies, ['working_dir', 'external_path', 'use_http'])
update_tree_step = (update.update_tree, ['working_dir'])


class UpdateTest(StepsBasedSubCommandTestMixin, unittest.TestCase):

    sub_command_name = 'update'
    sub_command_class = update.SubCommand
    expected_arguments = get_arguments()
    expected_handlers = (
        handlers.handle_working_dir,
        )
    expected_steps = (
        init_dir_step,
        update_dep_step,
        update_tree_step,
        )
    needs_root = False
